=====
Usage
=====

To use GreetCute in a project::

    from greetcute.greetcute import greet

To create an unbelievably stupendous greeting::

    greeting = greet()

And then… ::

    print(greeting)
    Hello you luxurious rain drop! I think you're super swell.
